@@ -159,14 +159,14 @@ class P100():
 			raise Exception(f"Error Code: {errorCode}, {errorMessage}")
 
 	def turnOn(self):
-		URL = f"http://192.168.0.157/app?token={self.token}"
+		URL = f"http://{self.ipAddress}/app?token={self.token}"
 		Payload = {
 			"method": "set_device_info",
 			"params":{
 				"device_on": True
 			},
 			"requestTimeMils": int(round(time.time() * 1000)),
-			"terminalUUID": "1C-3B-F3-A5-71-E5"
+			# "terminalUUID": "1C-3B-F3-A5-71-E5"
 		}
 
 		headers = {
@@ -191,14 +191,14 @@ class P100():
 			errorMessage = self.errorCodes[str(errorCode)]
 
 	def turnOff(self):
-		URL = f"http://192.168.0.157/app?token={self.token}"
+		URL = f"http://{self.ipAddress}/app?token={self.token}"
 		Payload = {
 			"method": "set_device_info",
 			"params":{
 				"device_on": False
 			},
 			"requestTimeMils": int(round(time.time() * 1000)),
-			"terminalUUID": "1C-3B-F3-A5-71-E5"
+			# "terminalUUID": "1C-3B-F3-A5-71-E5"
 		}
 
 		headers = {
